@@ -1,5 +1,5 @@
 """Synonym information."""
-from dataclasses import dataclass, field
+from dataclasses import dataclass
 
 
 @dataclass
